@@ -15,6 +15,10 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+# Import the list of JVMs
+
+. /usr/lib/java-wrappers/jvm-list.sh
+
 # Display a debugging message
 java_debug() {
     if [ "$DEBUG_WRAPPER" ]; then
@@ -37,16 +41,8 @@ java_fail() {
 # If JAVA_CMD exists, nothing is done. If JAVA_HOME exists, only that
 # is searched.
 #
-# In the other cases, the runtime is looked for according to the
-# following arguments:
-#  * 2 : java runtime 2 
-#  * swing : a JVM that has swing
-#  * fullxml: a JVM that has all XML classes, including
-#    javax.xml.stream.util.StreamReaderDelegate
-#  * sun: sun's JVM, for stuff depending on the infamous com.sun classes
-#  * sun6: sun's JVM version 6
-#  * icedtea: icedtea
-#  * openjdk: openjdk6
+# The full list of JVM names understood can be found in the file
+# /usr/lib/java-wrappers/jvm-list.sh.
 #
 # More than one argument can be specified; they will be taken into account
 # in that order; the first one found will be selected.
@@ -56,36 +52,6 @@ java_fail() {
 #
 # This information is currently *far from complete* !!!
 find_java_runtime() {
-    # First, known runtimes:
-
-    sun5="/usr/lib/jvm/java-1.5.0-sun /usr/lib/j2*1.5-sun"
-    sun4="/usr/lib/j2*1.4-sun"
-    sun6="/usr/lib/jvm/java-6-sun /usr/lib/j2*1.6-sun"
-    
-    sun_java="$sun4 $sun5 $sun6"
-    
-    gcj2="/usr/lib/jvm/java-*-gcj-4.* "
-    sablevm="/usr/lib/sablevm"
-    kaffe="/usr/lib/kaffe /usr/lib/kaffe/pthreads /usr/lib/kaffe/jthreads"
-    icedtea="/usr/lib/jvm/java-7-icedtea"
-    cacao="/usr/lib/jvm/cacao"
-    
-    openjdk6="/usr/lib/jvm/java-6-openjdk"
-
-    # IBM, coming from argouml.sh
-    ibm="/usr/lib/j2*1.[456]-ibm"
-
-    # Then, classes of JVM:
-    all_runtimes="$gcj2 $cacao $sablevm $kaffe $icedtea $sun_java $ibm /usr/lib/jvm/*"
-
-    # Java2 runtimes:
-    java2_runtimes="$gcj2 $iced_tea $sun_java $ibm"
-
-    # Full swing runtimes:
-    full_swing_runtimes="$iced_tea $sun_java $ibm"
-
-    # Sun java apparently has some XML functions more than concurrents:
-    xml_extra="/usr/lib/jvm/java-6-sun /usr/lib/jvm/java-1.5.0-sun"
 
     if [ "$JAVA_CMD" ]; then
 	if which "$JAVA_CMD" > /dev/null; then
@@ -114,38 +80,31 @@ find_java_runtime() {
     if [ -z "$JAVA_HOME" ]; then
 
         # We now try to look for a reasonable JAVA_HOME.
-        # First, narrow the choices, approximately according to what
-        # was asked
+        # First, narrow the choices according to what
+        # was asked.
+	#
+	# Please see the list of understood jvms in
+	# /usr/lib/java-wrappers/jvm-list.sh
 
 	DIRS=""
+
+	# If no arguments are given, we take it as 'all'
+	if test -z "$1"; then
+	    set all
+	fi
+	
 	while test "$1"
 	do 
-	    case $1 in
-	        # A java2 runtime
-		2) DIRS="$DIRS $java2_runtimes"
-		    ;;
-		swing) DIRS="$DIRS $icedtea $sun_java";
-		    ;;
-		sun) DIRS="$DIRS $sun_java"
-		    ;;
-		sunmax5) DIRS="$DIRS $sun4 $sun5"
-		    ;;
-		sunmin5) DIRS="$DIRS $sun5 $sun6"
-		    ;;
-		sun6) DIRS="$DIRS $sun6"
-		    ;;
-		fullxml) DIRS="$DIRS $xml_extra"
-		    ;;
-		icedtea) DIRS="$icedtea"
-		    ;;
-		openjdk) DIRS="$openjdk6"
-		    ;;
-		*) ;;
-	    esac
-	    shift
+	    found_jvm=$(eval "echo -n \$__jvm_$1")
+	    if [ -z "$found_jvm" ]; then
+		java_warning "JVM flavor '${1:-none}' not understood"
+	    else
+		DIRS="$DIRS $found_jvm"
+		shift
+	    fi
 	done
 	# Nothing means everything
-	if test -z "$DIRS"; then
+	if [ -z "$DIRS" ]; then
 	    DIRS=$all_runtimes
 	fi
         # And pick up the first one that works reasonably
@@ -168,7 +127,7 @@ find_java_runtime() {
 	java_debug "Found JAVA_CMD = '$JAVA_CMD'"
 	return 0		# Fine
     else
-	java_warning "No java runtime was found for flavor '${1:-none}'"
+	java_warning "No java runtime was found"
 	return 1;
     fi
 }
